"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiscriminatorValue = void 0;
const change_case_1 = require("change-case");
const jsonEntityFn_1 = require("../common/jsonEntityFn");
/**
 * Declare a Discriminator value on a child class.
 *
 * ```ts
 * export class Event {
 *   @DiscriminatorKey() // declare this property a discriminator key
 *   type: string;
 *
 *   @Property()
 *   value: string;
 * }
 *
 * @DiscriminatorValue("page_view")
 * export class PageView extends Event {
 *   @Required()
 *   url: string;
 * }
 *
 * @DiscriminatorValue("action")
 * export class Action extends Event {
 *   @Required()
 *   event: string;
 * }
 *
 * @DiscriminatorValue()
 * export class CustomAction extends Event {
 *   @Required()
 *   event: string;
 *
 *   @Property()
 *   meta: string;
 * }
 * ```
 *
 * @decorator
 * @swagger
 * @schema
 * @classDecorator
 * @param value
 * @param values
 */
function DiscriminatorValue(value, ...values) {
    return (0, jsonEntityFn_1.JsonEntityFn)((store) => {
        value = value || (0, change_case_1.snakeCase)(store.targetName);
        if (store.discriminatorAncestor) {
            store.schema.discriminatorValue(value, ...values);
        }
    });
}
exports.DiscriminatorValue = DiscriminatorValue;
//# sourceMappingURL=discriminatorValue.js.map