"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonResponse = void 0;
const mapHeaders_1 = require("../utils/mapHeaders");
const toJsonMapCollection_1 = require("../utils/toJsonMapCollection");
const JsonMap_1 = require("./JsonMap");
const JsonMedia_1 = require("./JsonMedia");
class JsonResponse extends JsonMap_1.JsonMap {
    $kind = "operationResponse";
    status;
    constructor(obj = {}) {
        super(obj);
        this.content(obj.content || {});
    }
    description(description) {
        this.set("description", description);
        return this;
    }
    headers(headers) {
        this.set("headers", (0, mapHeaders_1.mapHeaders)(headers));
        return this;
    }
    content(content) {
        this.set("content", (0, toJsonMapCollection_1.toJsonMapCollection)(content, JsonMedia_1.JsonMedia));
        return this;
    }
    getContent() {
        return this.get("content");
    }
    getMedia(mediaType, create = true) {
        create && this.addMedia(mediaType);
        return this.getContent()?.get(mediaType);
    }
    addMedia(mediaType) {
        const content = this.get("content");
        if (!content.has(mediaType)) {
            content.set(mediaType, new JsonMedia_1.JsonMedia());
        }
        return this;
    }
}
exports.JsonResponse = JsonResponse;
//# sourceMappingURL=JsonResponse.js.map