import { cleanObject } from "@tsed/core";
import { registerJsonSchemaMapper } from "../../registries/JsonSchemaMapperContainer.js";
import { createRefName } from "../../utils/ref.js";
function inlineReference(parameter, { jsonParameter, ...options }) {
    const name = createRefName(jsonParameter.$schema.getName(), options);
    const schema = options.components?.schemas?.[name];
    if (schema && !options.oldSchemas?.[name]) {
        delete options.components.schemas[jsonParameter.$schema.getName()];
    }
    return Object.entries(schema?.properties || {}).reduce((params, [key, { description, ...prop }]) => {
        return [
            ...params,
            cleanObject({
                ...parameter,
                name: key,
                required: (schema?.required || []).includes(key),
                description,
                schema: prop,
                style: prop.$ref ? "deepObject" : undefined
            })
        ];
    }, []);
}
export function operationInQueryMapper(parameter, { jsonSchema, jsonParameters, ...options }) {
    if (jsonSchema.$ref) {
        if (!parameter.name) {
            return inlineReference(parameter, options);
        }
        parameter.style = "deepObject";
    }
    parameter.schema = jsonSchema;
    return parameter;
}
registerJsonSchemaMapper("operationInQuery", operationInQueryMapper);
//# sourceMappingURL=operationInQueryMapper.js.map